@@ -21,6 +21,7 @@ import showlog
 import json
 import envx
 import sys
+import requests
 
 # datahub安装时使用pydatahub
 
@@ -237,6 +238,7 @@ class Basics:
             blob_data: str = 'blob_data',  # 可以存入字符串类型的字典
             attribute: dict = None,  # 只能传入单层字典
             shard_id='0',  # 指定shard_id，默认为'0'
+            auto_retry: bool = True
     ):
         """
         存入blob数据
@@ -260,47 +262,66 @@ class Basics:
             }
             return res
 
-        try:
-            records_list = list()
-            temp_blob_record = BlobRecord(blob_data=blob_data)
-            temp_blob_record.shard_id = shard_id
-            if attribute is not None:
-                for key, value in attribute.items():
-                    temp_blob_record.put_attribute(str(key), str(value))
-            else:
-                pass
-            records_list.append(temp_blob_record)
-            put_result = self.dh.put_records(
-                project_name=project_name,
-                topic_name=topic_name,
-                record_list=records_list
-            )
-            failed_record_count = put_result.to_json().get('FailedRecordCount')
-            if failed_record_count is not None and failed_record_count == 0:
+        while True:
+            try:
+                records_list = list()
+                temp_blob_record = BlobRecord(blob_data=blob_data)
+                temp_blob_record.shard_id = shard_id
+                if attribute is not None:
+                    for key, value in attribute.items():
+                        temp_blob_record.put_attribute(str(key), str(value))
+                else:
+                    pass
+                records_list.append(temp_blob_record)
+                put_result = self.dh.put_records(
+                    project_name=project_name,
+                    topic_name=topic_name,
+                    record_list=records_list
+                )
+                failed_record_count = put_result.to_json().get('FailedRecordCount')
+                if failed_record_count is not None and failed_record_count == 0:
+                    res = {
+                        "code": 0,
+                        "message": "success",
+                        "data": put_result.to_json()
+                    }
+                    return res
+                else:
+                    # 保存错误log
+                    showlog.warning(put_result)
+                    res = {
+                        "code": -1,
+                        "message": put_result.to_json(),
+                        "data": ""
+                    }
+                    return res
+            except ConnectionResetError:
+                if auto_retry:
+                    showlog.warning('ConnectionResetError 连接错误，将重试...')
+                    continue
+                else:
+                    break
+            except ConnectionError:
+                if auto_retry:
+                    showlog.warning('ConnectionError 连接错误，将重试...')
+                    continue
+                else:
+                    break
+            except requests.exceptions.ConnectionError:
+                if auto_retry:
+                    showlog.warning('ConnectionError 连接错误，将重试...')
+                    continue
+                else:
+                    break
+            except DatahubException as e:
+                # 404:NoSuchTopic
+                showlog.warning(e)
                 res = {
-                    "code": 0,
-                    "message": "success",
-                    "data": put_result.to_json()
-                }
-                return res
-            else:
-                # 保存错误log
-                showlog.warning(put_result)
-                res = {
-                    "code": -1,
-                    "message": put_result.to_json(),
+                    "code": e.status_code,
+                    "message": e,
                     "data": ""
                 }
                 return res
-        except DatahubException as e:
-            # 404:NoSuchTopic
-            showlog.warning(e)
-            res = {
-                "code": e.status_code,
-                "message": e,
-                "data": ""
-            }
-            return res
 
     def blob_records_read(
             self,
@@ -567,7 +588,7 @@ def topic_list(
 
 
 def lazy_save(
-        data: dict,
+        data,
         save_project_name: str,
         save_topic_name: str,
         save_env_file_name_datahub: str,
@@ -597,10 +618,14 @@ def lazy_save(
     }
     try:
         while True:
+            if isinstance(data, dict):
+                blob_data = json.dumps(data)
+            else:
+                blob_data = data
             add_response = blob_records_add(
                 project_name=save_project_name,
                 topic_name=save_topic_name,
-                blob_data=json.dumps(data),
+                blob_data=blob_data,
                 env_file_name=save_env_file_name_datahub,
                 project_auto_create=project_auto_create,
                 topic_auto_create=topic_auto_create
@@ -630,6 +655,7 @@ def lazy_save(
                     )
                 return save_res
     except:
+        showlog.error('出错了')
         if error_to_redis is True:
             try:
                 # 出错的转存到redis
@@ -641,8 +667,8 @@ def lazy_save(
                 )
             except:
                 save_res = {
-                    "code": 1,
-                    "msg": "failed",
+                    "code": 2,
+                    "msg": "failed to save redis",
                     "success": False
                 }
         else:
